/**
* Formular für neuen Ordner bzw. neue Datei
*/
function NewAnyfileForm(
    objBtnBar,      // Zuständige Menüleiste
    filemanager,    // Zuständige FileManager-Instanz
) {
    var self = this;
    this.objBtnBar = objBtnBar;
    this._filemanager = filemanager;
    var dir = filemanager._current;
    this._dir = dir;
    var objBubble = objBtnBar.showBubble();

    var dirnr = '';
    while (dir.hasFile('Datei' + dirnr))
        ++dirnr;
    this._inputName = new ValidatedTextForm(objBubble.node, {
        label: 'Datei-/Ordnername:',
        placeholder: 'Datei- bzw. Ordnername',
        text: 'Datei' + dirnr,
        onvalidate(text) { return NewAnyfileForm.validateFilename(this, text, dir); }
    });

    var submenu = new BtnBar(objBubble.node, true, objBubble, true);
    submenu.add([
        { label: 'Ordner erstellen', className: 'btn_dir', title: 'Einen neuen Ordner mit dem eingegebenen Namen erstellen', onclick: function() {
            self.createFile(true);
        } },
        { label: 'Leere Datei erstellen', className: 'btn_emptyfile', title: 'Einen neue leere Datei mit dem eingegebenen Namen erstellen', onclick: function() {
            self.createFile(false);
        } }
    ]);
    if (filemanager.useClipboard)
        submenu.add([
            { label: 'Aus Zwischenablage', className: 'btn_paste', title: 'Inhalt der Zwischenablage mit geändertem Dateinamen einfügen', disabled: !(self._filemanager.clipboard instanceof Anyfile), onclick: function() {
                var file = self._filemanager.clipboard;
                if (!self._filemanager.boolMove)
                    file = file.clone(true);
                file._filename = self.filename;
                self._filemanager._current.addFile(file);
                self._filemanager.selectFilename(self.filename);
            } }
        ]);
    submenu.add([
        true,
        { label: 'Zurück', className: 'btn_close', title: 'Dieses Menü schließen' }
    ]);

    this._inputName.focus();
    this._inputName.select();
}

/**
* Prüfen, ob ein Dateiname erlaubt, noch frei und kein Pfad ist
* @return Boolean   Erlaubt?
*/
NewAnyfileForm.validateFilename = function(
    form,       // ValidatedTextForm-Instanz
    filename,   // Gewünschter Dateiname
    dir         // Aktuelles Verzeichnis
) {
    if (!filename.length) {
        form.strMessage = 'Der Name darf nicht leer sein';
        return false;
    }
    if (dir.hasFile(filename)) {
        form.strMessage = 'Diese Datei existiert bereits';
        return false;
    }
    switch (filename) {
        case '.':
        case '..':
            form.strMessage = '. und .. sind nicht erlaubt';
            return false;
    }
    if (filename.indexOf('/') != -1) {
        form.strMessage = 'Der Name darf kein / beinhalten';
        return false;
    }
    form.strMessage = 'Gültiger Name';
    return true;
}

// Dateiname
Object.defineProperty(NewAnyfileForm.prototype, 'filename', {
    get() {
        return this._inputName.text;
    },
    set(value) {
        this._inputName.text = value;
    }
});

// Zuständige Menüleiste
NewAnyfileForm.prototype.objBtnBar = null;

// Was soll beim Absenden des Formulars passieren?
NewAnyfileForm.prototype.onsubmit = null;

/**
* Überprüfen, ob der eingegebene Dateiname erlaubt ist
* @return Boolean   Ist der Dateiname erlaubt?
*/
NewAnyfileForm.prototype.validateFilename = function() {
    return this._inputName.validate();
}

/**
* Wenn der eingegebene Dateiname erlaubt ist, Datei anlegen und Dialogblase schließen
* @return undefined
*/
NewAnyfileForm.prototype.createFile = function(
    isDir       // Statt einer leeren Datei einen Ordner anlegen
) {
    if (!this.validateFilename())
        return;
    var f = new Anyfile(this._filemanager);
    f.filename = this.filename;
    if (isDir)
        f.isDir = isDir;
    this._filemanager._current.addFile(f);
    this.objBtnBar.closeBubble();
    this._filemanager.selectFilename(this.filename);
}
